# Electric Units for python

Python objects to ease the handling of data around electricity systems and grids.

![Electric Units for python](/extras/retrowave-logo.jpg)

## Installation

`pip install electric-units` will install from pypi

Or, you can view or checkout the source from [Github](https://github.com/ample-tech/electric-units) and `python setup.py install` will install the package and its
dependancies.

## Development
This has come of the needs we keep running into when dealing with data from
electricity systems - if you find these useful and want to change or add to
the units, please do!

If you've never contributed to open source before - even better. We are here
to help you make your first PR and will make an effort to create and reserve
issue for [first timers only](https://www.firsttimersonly.com).

### Reporting issues
If you run into an issue with the use of this library, please report a bug in our
(github issues tab)[https://github.com/ample-tech/electric-units/issues].

From there, you'll receive help, or we can work on fixing the bug.

### Getting involved

Check our [Code of Conduct here](https://github.com/ample-tech/electric-units/blob/master/CODE_OF_CONDUCT.md)

Once you've cloned the code you can run the test suit with `python setup.py test`.
This will install all of the required dependancies, check that the current tests
pass and that the code is lint free.


## Usage

See the post on [kyso.io for some basic usage instructions](https://kyso.io/ample/electric-units).
